#ifndef ENGINE_H_
#define ENGINE_H_

#include <QObject>
#include <QDateTime>
#include "Room.h"

class QTimer;
class Clock;
class Configuration;
class CommunicationManager;
class Meeting;
class DeviceManager;

//! BusinessLogic class.
/*!
 * BusinessLogic class that contains all the business logic of the application. It is responsible
 * for connecting user interface to lower layers (IO).
 */
class Engine : public QObject
{
	Q_OBJECT

public:
	//! Constructor.
	/*!
	 * Constructor to initialize an Engine instance.
	 */
	Engine();
	//! Destructor.
	virtual ~Engine();

	Clock* clock();
	Configuration* configuration();
	Room* defaultRoom();

signals:
	void initializationFailed();
	void roomStatusChanged( Room *aRoom, Room::Status aStatus, QTime aUntil );
	void meetingAdded( Meeting *aMeeting );
	void meetingDeleted( Meeting *aMeeting );
	void error( const QString &aErrorMessage );

public slots:
	void roomStatusInfoNeeded( Room *aRoom );
	void fetchMeetings( const QDateTime &aFrom, const QDateTime &aUntil, Room *aIn );
	void createMeeting( const Meeting *aMeeting, const QString &aUsername, const QString &aPassword );
	void updateMeeting( const Meeting *aMeeting, const QString &aUsername, const QString &aPassword );
	void deleteMeeting( const Meeting *aMeeting, const QString &aUsername, const QString &aPassword );

private slots:
	void errorHandler( int aCode );
	void fetchMeetings();
	void meetingsFetched( QList<Meeting*> aMeetings );
	void checkStatusOfAllRooms();

private:
	int indexOfMeetingAt( Room *aRoom, QDateTime aAt );
	int indexOfMeetingAfter( Room *aRoom, QDateTime aAfter );
	bool isMeetingInList( QList<Meeting*> aList, Meeting *aMeeting );

private:
	static QTime endOfTheDay;

	Clock *iClock;
	Configuration *iConfiguration;
	CommunicationManager *iCommunication;
	DeviceManager *iDevice;

	QTimer *iAutoRefresh;

	QList<Meeting*> iMeetings;

};

#endif /*ENGINE_H_*/
