#include "Meeting.h"
#include "Room.h"

Meeting::Meeting( Room *aRoom, QDateTime aStartsAt, QDateTime aEndsAt, const QString &aOrganizer, const QString &aSubject )
{
	iRoom = aRoom;
	iStartsAt = aStartsAt;
	iEndsAt = aEndsAt;
	iOrganizer = aOrganizer;
	iSubject = aSubject;
}

Meeting::~Meeting()
{
}

Room* Meeting::room()
{
	return iRoom;
}

QString Meeting::organizer()
{
	return iOrganizer;
}

QDateTime Meeting::startsAt()
{
	return iStartsAt;
}

QDateTime Meeting::endsAt()
{
	return iEndsAt;
}

QString Meeting::subject()
{
	return iSubject;
}

void Meeting::setStartsAt( QDateTime aNewStart )
{
	iStartsAt = aNewStart;
}

void Meeting::setEndsAt( QDateTime aNewEnd )
{
	iEndsAt = aNewEnd;
}

void Meeting::setSubject( const QString &aSubject )
{
	iSubject = aSubject;
}

bool Meeting::equals( Meeting *aOther )
{
	if ( iRoom->equals( aOther->room() )
		  && iStartsAt == aOther->startsAt()
		  && iEndsAt == aOther->endsAt()
		  && iOrganizer == aOther->organizer() )
	{
		return true;
	}
	return false;
}

bool Meeting::overlaps( Meeting* aOther )
{
	return (( iStartsAt >= aOther->iStartsAt && iStartsAt < aOther->iEndsAt ) ||
		  ( iStartsAt <= aOther->iStartsAt && iEndsAt > aOther->iStartsAt ) );
}

QString Meeting::toString()
{
	QString meetingToString = QString( "[MEETING: in:%1 from:%2 until:%3 by:%4 subject:%5]" )
					  .arg( iRoom->toString() )
					  .arg( iStartsAt.toString() )
					  .arg( iEndsAt.toString() )
					  .arg( iOrganizer )
					  .arg( iSubject );

	return meetingToString;
}
