#ifndef MEETING_H_
#define MEETING_H_

#include <QString>
#include <QDateTime>

class Room;

//! Domain class.
/*!
 * Domain class describes appointments.
 */
class Meeting
{
public:
	//! Constructor.
	/*!
	 * Constructor to initialize a Meeting instance.
	 * \param aRoom Pointer to the Room instance where the meeting will be held.
	 * \param aStartsAt The date and time when the meeting starts.
	 * \param aEndsAt The date and time when the meeting ends.
	 * \param aOrganizer The e-mail address of the organizer.
	 * \param aSubject The subject of the meeting.
	 */
	Meeting( Room *aRoom, QDateTime aStartsAt, QDateTime aEndsAt, const QString &aOrganizer, const QString &aSubject = "" );
	//! Destructor.
	virtual ~Meeting();

	Room* room();
	QString organizer();
	QDateTime startsAt();
	QDateTime endsAt();
	QString subject();

	void setStartsAt( QDateTime aNewStart );
	void setEndsAt( QDateTime aNewEnd );
	void setSubject( const QString &aSubject );

	bool equals( Meeting *aOther );
	bool overlaps( Meeting* aOther );
	QString toString();

private:
	Room *iRoom;
	QString iOrganizer;
	QDateTime iStartsAt;
	QDateTime iEndsAt;
	QString iSubject;

};

#endif /*MEETING_H_*/
