#include "DeviceDataStorage.h"

#include <QtDebug>
#include <QFile>
#include <QTextStream>

const QString FILENAME = "/var/local/ixonosmeetings.txt";

DeviceDataStorage::DeviceDataStorage()
{

}

DeviceDataStorage::~DeviceDataStorage()
{

}

bool DeviceDataStorage::readData( QString aSection, QList<QString> &aData, bool aRemove )
{
	QFile rFile( FILENAME );
	QFile wFile( FILENAME + ".tmp" );

	if ( !rFile.open( QIODevice::ReadOnly | QIODevice::Text ) )
		return false;
	if ( !wFile.open( QIODevice::WriteOnly | QIODevice::Text ) )
		return false;

	QTextStream in( &rFile );
	QTextStream out( &wFile );

	QString section = "[" + aSection + "]";
	bool storeData = false;

	while ( !in.atEnd() )
	{
		QString line = in.readLine();
		if ( storeData )
		{
			if ( line.length() > 0 )
			{
				//check if this is already the next section
				if ( line.at( 0 ) == QChar( '[' ) && line.at( line.length() - 1 ) == QChar( ']' ) )
				{
					storeData = false;
					if ( aRemove )
						out << line << "\n";
				}
				else
				{
					qDebug() << "JAKEKAKE: " << line;
					aData.append( line );
				}
			}
		}
		else
		{
			if ( aRemove )
				out << line << "\n";
			if ( line == section )
				storeData = true;
		}
	}
	rFile.close();
	wFile.close();
	if ( aRemove )
	{
		if ( !rFile.remove() )
			return false;
		if ( !wFile.rename( FILENAME ) )
		{
			return false;
		}
	}
	return true;
}

bool DeviceDataStorage::storeData( QString aSection, QList<QString> aData )
{
	QFile rFile( FILENAME );
	QFile wFile( FILENAME + ".tmp" );

	if ( !rFile.open( QIODevice::ReadOnly | QIODevice::Text ) )
		return false;
	if ( !wFile.open( QIODevice::WriteOnly | QIODevice::Text ) )
		return false;

	QTextStream in( &rFile );
	QTextStream out( &wFile );

	QString section = "[" + aSection + "]";
	bool skipOldData = false;
	bool sectionFound = false;

	while ( !in.atEnd() )
	{
		QString line = in.readLine();
		if ( !skipOldData )
			out << line << "\n";
		else
		{
			//check if this is already the next section
			if ( line.length() > 0 )
			{
				if ( line.at( 0 ) == QChar( '[' ) && line.at( line.length() - 1 ) == QChar( ']' ) )
				{
					skipOldData = false;
					out << line << "\n";
				}
			}
		}
		if ( line == section )
		{
			qDebug() << " section found";
			sectionFound = true;
			skipOldData = true;
			for ( int i = 0; i < aData.size(); ++i )  //replace old section data with new one
			{
				qDebug() << " put data " << aData.at( i );
				out << aData.at( i ) << "\n";
			}
		}
	}

	//we didn't find the section at all
	if ( !sectionFound )
	{
		out << section << "\n";
		for ( int i = 0; i < aData.size(); ++i )
			out << aData.at( i ) << "\n";
	}

	rFile.close();
	wFile.close();

	if ( !rFile.remove() )
		return false;
	if ( !wFile.rename( FILENAME ) )
	{
		qDebug() << "renaming failed";
		return false;
	}
	return true;
}
