#include "DeviceManager.h"
#include "AlarmSender.h"
#include "HWKeyListener.h"
#include "StartupSettings.h"
#include "DeviceDataStorage.h";

#include <QtDebug>
#include <QStringList>
#include <QProcess>

DeviceManager::DeviceManager( StartupSettings *aSettings )
{
	iMode = StandAloneMode;
	iSettings = aSettings;

	iAlarmSender = new AlarmSender();

	//testing
	//toggleScreenSwitchOff( false );
	//iAlarmSender->sendAlarms( QTime( 5, 0 ), QTime( 15, 0 ) );

	iHWKeyListener = new HWKeyListener();
	connect( iHWKeyListener, SIGNAL( HWKeyFullScreenPressed() ), this, SLOT( changeMode() ) );

	iDataStorage = new DeviceDataStorage();

	//testing
	QString section = "kake";
	QList<QString> data;
	data.append( "jake" );
	data.append( "jake" );

	iDataStorage->storeData( section, data );

	data.clear();
	iDataStorage->readData( section, data, true );
	qDebug() << "Data from section " << section << " is ";
	for ( int i = 0; i < data.size(); ++i )
		qDebug() << data.at( i );
}

DeviceManager::~DeviceManager()
{
}

void DeviceManager::changeMode()
{
	if ( iMode == StandAloneMode && iSettings->isPowersavingEnabled() )
	{
		iAlarmSender->sendAlarms( iSettings->turnOnAt(), iSettings->turnOffAt() );
		toggleScreenSwitchOff( false );
		iMode == KioskMode;
	}
	else
	{
		iAlarmSender->removeAlarms();
		iMode == StandAloneMode;
	}
}

void DeviceManager::toggleScreenSwitchOff( bool aEnable )
{
	QString command = "gconftool-2";
	QStringList args;
	QByteArray result;

	if ( !aEnable )
	{
		args << "-s" << "/system/osso/dsm/display/display_dim_timeout" << "--type=int" << "6000000";
		systemIO( command, args, result );
		args[1] = "/system/osso/dsm/display/display_blank_timeout";
		systemIO( command, args, result );
		args[1] = "/system/osso/dsm/display/display_dim_timeout";
		systemIO( command, args, result );
		args[1] = "/apps/osso/applet/osso-applet-display/turn_off_display";
		systemIO( command, args, result );
		args[1] = "/apps/osso/applet/osso-applet-display/brightness_period";
		systemIO( command, args, result );
	}
	else
	{
		args << "-g" << "/system/osso/dsm/display/display_dim_timeout";
		systemIO( command, args, result );
		/*system( "gconftool-2 -g /system/osso/dsm/display/display_blank_timeout" );
		system( "gconftool-2 -g /apps/osso/applet/osso-applet-display/turn_off_display" );
		system( "gconftool-2 -g /apps/osso/applet/osso-applet-display/brightness_period" );*/
	}
}

bool DeviceManager::systemIO( QString aCommand, QStringList aArgs, QByteArray &aResult )
{
	QProcess process;
	process.start( aCommand, aArgs );
	if ( !process.waitForFinished() )
		return false;
	aResult = process.readAll();
}

