#ifndef DIGITALTIMEDISPLAYWIDGET_H_
#define DIGITALTIMEDISPLAYWIDGET_H_

#include "TimeDisplayWidget.h"

class QLCDNumber;

//! Userinterface class to display time.
/*!
 * DigitalTimeDisplayWidget inferits TimeDisplayWidget and diplays time in
 * QLCDNumber display.
 */
class DigitalTimeDisplayWidget : public TimeDisplayWidget
{
	Q_OBJECT

public:

	//! Constructor.
	/*!
	 * Basic constructor of TimeDisplayWidget.
	 * \param aNow Current time
	 * \param aFormat Time display format
	 * \param aParent Parent widget
	 */
	DigitalTimeDisplayWidget( QTime aNow, QString aFormat, QWidget *parent = 0 );
	//! Destructor
	virtual ~DigitalTimeDisplayWidget();

	//! Set frame visibility
	/*!
	 * \param aVisible True, if frame is drawn, otherwise false.
	 */
	virtual void setFrameVisible( bool aVisible );
	//! Set size
	/*!
	 * \param aWidth
	 * \param aHeight
	 */
	virtual void setSize( int aWidth, int aHeight );
	//! Set Font
	/*!
	 * \param aFont
	 */
	virtual void setFont( const QFont &aFont );

protected:
	//! Displays the time.
	/*!
	 * Displays the time in LCD number display.
	 */
	virtual void showTime();

private:
	//! Display to show the time.
	QLCDNumber *iDisplay;
	//! Format used to show time.
	QString iTimeFormat;

};

#endif /*DIGITALTIMEDISPLAYWIDGET_H_*/
