#include "RoomStatusIndicatorWidget.h"

#include <QLabel>
#include <QFont>
#include <QVBoxLayout>
#include "DigitalTimeDisplayWidget.h"
#include "ToolBox.h"

#include <QtDebug>

QTime RoomStatusIndicatorWidget::endOfTheDay = QTime( 23, 59, 0, 0 );

RoomStatusIndicatorWidget::RoomStatusIndicatorWidget( Room *aDefaultRoom, Room::Status aStatus, QTime aUntil, QString aFormat, QWidget *aParent ) :
		ObservedWidget( aParent ), iTimeFormat( aFormat )
{
	QFont importantTextFont;
	importantTextFont.setBold( true );
	importantTextFont.setPointSize( 20 );

	QFont regularTextFont;
	regularTextFont.setBold( true );
	regularTextFont.setPointSize( 12 );

	// Pegasus
	iDefaultRoomLabel = ToolBox::createLabel( aDefaultRoom->name(), importantTextFont );
	// is
	QLabel *labelIS = ToolBox::createLabel( tr( "is" ), regularTextFont );
	// Busy
	iStatusLabel = ToolBox::createLabel( statusToText( aStatus ), importantTextFont );
	// until
	iUntilTextLabel = ToolBox::createLabel( tr( "until" ), regularTextFont );
	// 13:22
	iUntilTimeLabel = ToolBox::createLabel( aUntil.toString( iTimeFormat ), importantTextFont );

	// display for current time
	// Note: the time display receives current time info from Engine::clock()
	iTimeDisplay = new DigitalTimeDisplayWidget( QTime::currentTime(), iTimeFormat, this );
	iTimeDisplay->setFrameVisible( false );

	QHBoxLayout *topLayout = new QHBoxLayout;
	topLayout->addWidget( iDefaultRoomLabel );
	topLayout->addWidget( labelIS );
	topLayout->addWidget( iStatusLabel );
	topLayout->addWidget( iUntilTextLabel );
	topLayout->addWidget( iUntilTimeLabel );

	QVBoxLayout *mainLayout = new QVBoxLayout;
	mainLayout->addLayout( topLayout );
	mainLayout->addWidget( iTimeDisplay );
	setLayout( mainLayout );

	statusChanged( aStatus, aUntil );

	setFocusPolicy( Qt::StrongFocus );
	setEnabled( true ); // enable mouse & key events
}

RoomStatusIndicatorWidget::~RoomStatusIndicatorWidget()
{
	delete iTimeDisplay;
	iTimeDisplay = 0;
}

QString RoomStatusIndicatorWidget::statusToText( const Room::Status aStatus )
{
	return ( aStatus == Room::BusyStatus ) ? tr( "Busy" ) : tr( "Free" );
}

QPalette RoomStatusIndicatorWidget::createPalette( Room::Status aStatus )
{
	QPalette palette;
	QColor color = ( aStatus == Room::BusyStatus ) ? Qt::red : Qt::darkGreen;
	palette.setColor( QPalette::Window, color );
	return palette;
}

void RoomStatusIndicatorWidget::setCurrentTime( QTime aCurrentTime )
{
	iTimeDisplay->setTime( aCurrentTime );
}

void RoomStatusIndicatorWidget::statusChanged( const Room::Status aStatus, const QTime aUntil )
{
	iStatusLabel->setText( statusToText( aStatus ) );
	if ( aUntil == RoomStatusIndicatorWidget::endOfTheDay )
	{
		iUntilTextLabel->setText( tr( "whole day." ) );
		iUntilTimeLabel->clear();
	}
	else
	{
		iUntilTextLabel->setText( tr( "until" ) );
		iUntilTimeLabel->setText( aUntil.toString( iTimeFormat ) );
	}
	setPalette( createPalette( aStatus ) );
}
