#ifndef WINDOWMANAGER_H_
#define WINDOWMANAGER_H_

#include <QObject>
#include <QTime>
#include "Room.h"
#include "Meeting.h"

class QTimer;
class RoomStatusIndicatorWidget;
class WeeklyViewWidget;
class Engine;
class MeetingInfoDialog;

//! Userinterface class to display views.
/*!
 * WindowManager displays the views and forwards the messages between engine and
 * views and also between different views.
 */
class WindowManager : public QObject
{
	Q_OBJECT

public:
	//! Constructor.
	/*!
	 * Constructor of WindowManager.
	 */
	WindowManager();
	//! Destructor.
	virtual ~WindowManager();

signals:
	//! Request current status of the room.
	/*!
	 * Signal is emitted when there is need to check current status of room aRoom.
	 * \param aRoom Meetingroom which status is requested.
	 */
	void roomStatusInfoNeeded( Room *aRoom );

private slots:
	//! Closes the application.
	void closeApplication();
	//! Updates the time.
	/*!
	 * Forwards the signal of changed time to current view.
	 * \param aCurrentDateTime Current date and time.
	 */
	void distributeDateTimeInfo( QDateTime aCurrentDateTime );
	//! Updates the rooms status.
	/*!
	 * Forwards the signal of changed status to current view.
	 * \param aRoom Room which status is changed.
	 * \param aStatus Current status of room.
	 * \param aTime Time when status is changed.
	 */
	void roomStatusChanged( Room *aRoom, Room::Status aStatus, QTime aTime );
	//! Displays the weekly view
	void showWeeklyView();
	//! Displays the screensaver (room status view)
	void showRoomStatus();
	/*!
	 * Displays the meeting info dialog
	 * \param aMeeting Meeting to be displayd
	 */
	void showMeetingInfo( Meeting *aMeeting );
	/*!
	 * Displays an error message
	 * \param aErrorMessage Message to be displayd
	 */
	void error( const QString &aErrorMessage );
	//! Restarts the timer to launch the screensaver.
	void observedEventDetected();

private:
	//! Name of the application.
	QString iApplicationName;
	//! Pointer to the weekly view.
	WeeklyViewWidget *iWeeklyView;
	//! Pointer to the screensaver (room status view).
	RoomStatusIndicatorWidget *iRoomStatusView;
	//! Pointer to the meeting info dialog
	MeetingInfoDialog *iMeetingInfo;
	//! Pointer to the engine.
	Engine *iEngine;
	//! Timer to launch the screensaver widget
	QTimer *iIdleTimeCounter;

};

#endif /*WINDOWMANAGER_H_*/
