#include <QtTest/QtTest>
#include "Meeting.h"
#include "Room.h"

class TestMeeting: public QObject
{
	Q_OBJECT

private slots:
	void initTestCase();
	void init();
	void cleanup();
	void testOrganizer();
	void testStartsAt();
	void testEndsAt();
	void testSubject();
	void testSetStartsAt();
	void testSetEndsAt();
	void testSetSubject();
	void testEquals();
	void testToString();
	void cleanupTestCase();

private:
	Meeting *iMeeting1, *iMeeting2;

	Room *iRoom;
	QString iOrganizer1, iOrganizer2;
	QDateTime iStartsAt1, iStartsAt2;
	QDateTime iEndsAt1, iEndsAt2;
	QString iSubject1, iSubject2;

};

void TestMeeting::initTestCase()
{
	iRoom = new Room( "Pegasus", "meetingroom.pegasus_jyv@ixonos.com" );
	QVERIFY( iRoom != 0 );

	iOrganizer1 = "Test Organizer";
	iOrganizer2 = "Another Organizer";

	QDateTime today( QDate( 2005, 12, 1 ), QTime( 12, 0, 0 ), Qt::UTC );

	iStartsAt1 = QDateTime( QDate( 2007, 3, 13 ), QTime( 13, 0, 0 ) );
	iStartsAt2 = QDateTime( QDate( 2007, 3, 14 ), QTime( 13, 0, 0 ) );

	iEndsAt1 = QDateTime( QDate( 2007, 3, 13 ), QTime( 14, 0, 0 ) );
	iEndsAt2 = QDateTime( QDate( 2007, 3, 14 ), QTime( 14, 0, 0 ) );

	iSubject1 = "Test subject";
	iSubject2 = "Another subject";

	iMeeting1 = new Meeting( iRoom, iStartsAt1, iEndsAt1, iOrganizer1, iSubject1 );
	QVERIFY( iMeeting1 != 0 );

	iMeeting2 = new Meeting( iRoom, iStartsAt1, iEndsAt1, iOrganizer1, iSubject1 );
	QVERIFY( iMeeting2 != 0 );
}

void TestMeeting::cleanupTestCase()
{
	delete iMeeting1;
	iMeeting1 = NULL;
	delete iMeeting2;
	iMeeting2 = NULL;
	delete iRoom;
	iRoom = NULL;
}

void TestMeeting::init()
{
	//qDebug("Debug line");
}

void TestMeeting::cleanup()
{
	//nothing to do
}

void TestMeeting::testOrganizer()
{
	QCOMPARE( iMeeting1->organizer(), iOrganizer1 );
}

void TestMeeting::testStartsAt()
{
	QCOMPARE( iMeeting1->startsAt(), iStartsAt1 );
}

void TestMeeting::testEndsAt()
{
	QCOMPARE( iMeeting1->endsAt(), iEndsAt1 );
}

void TestMeeting::testSubject()
{
	QCOMPARE( iMeeting1->subject(), iSubject1 );
}

void TestMeeting::testSetStartsAt()
{
	iMeeting1->setStartsAt( iStartsAt2 );
	QCOMPARE( iMeeting1->startsAt(), iStartsAt2 );

	iMeeting1->setStartsAt( iStartsAt1 );
	QCOMPARE( iMeeting1->startsAt(), iStartsAt1 );
}

void TestMeeting::testSetEndsAt()
{
	iMeeting1->setEndsAt( iEndsAt2 );
	QCOMPARE( iMeeting1->endsAt(), iEndsAt2 );

	iMeeting1->setEndsAt( iEndsAt1 );
	QCOMPARE( iMeeting1->endsAt(), iEndsAt1 );
}

void TestMeeting::testSetSubject()
{
	iMeeting1->setSubject( iSubject2 );
	QCOMPARE( iMeeting1->subject(), iSubject2 );

	iMeeting1->setSubject( iSubject1 );
	QCOMPARE( iMeeting1->subject(), iSubject1 );
}

void TestMeeting::testEquals()
{
	iMeeting2->setEndsAt( iEndsAt2 );
	QCOMPARE( iMeeting1->equals( iMeeting2 ), false );

	iMeeting2->setEndsAt( iEndsAt1 );
	QCOMPARE( iMeeting1->equals( iMeeting2 ), true );
}

void TestMeeting::testToString()
{
	QString meeting1ToString = QString( "[MEETING: in:%1 from:%2 until:%3 by:%4 subject:%5]" )
					   .arg( iRoom->toString() )
					   .arg( iStartsAt1.toString() )
					   .arg( iEndsAt1.toString() )
					   .arg( iOrganizer1 )
					   .arg( iSubject1 );

	QCOMPARE( iMeeting1->toString(), meeting1ToString );
}

QTEST_MAIN( TestMeeting )
#include "TestMeeting.moc"
